@@ -476,8 +476,6 @@ def spawn_workers(action, sequence, **kwargs):
     verbose = kwargs['verbose']
     debug = kwargs['debug']
     silent = kwargs['silent']
-    if verbose: print >>sys.stdout, ' '.join(['Using', str(max_cpus),
-                                              'cpu(s)...'])
     if debug: print_debug('Debugging mode enabled')
 
     used_cpus = min([NUM_CPUS, max_cpus])
@@ -491,6 +489,8 @@ def spawn_workers(action, sequence, **kwargs):
         if debug:
             print_debug('WARNING: multiprocessing enabled', os.linesep,
                         'debug output may get mangeled')
+        if verbose: print >>sys.stdout, ' '.join(['Using', str(used_cpus),
+                                              'cpu(s)...'])
         signal.signal(signal.SIGCHLD, signal.SIG_DFL)
         p = multiprocessing.Pool(processes=used_cpus)
         results = [p.apply_async(action, (item,), kwargs) for item in sequence]
